# Week 8: Displaying Data Visually Part 2
# Brett Favaro
# Oct 23, 2019

# RUN 001_datasetup.R first

#perch should be loaded into memory. 7328 obs of 5 vars

# Data are from: http://derekogle.com/fishR/data/data-html/YPerchTL.html
# obtained 23 Oct 2019

library(ggthemes)

#Data
#sampledate: Date of capture
#gearid: Capture gear type – beach seine (BSEINE), crayfish trap (CRAYTR), electrofishing (ELFISH), fyke net (FYKNET), trammel net (TRAMML), vertical gillnets of different mesh sizes (VBN0XX), and different types of fyke nets (FYKNED and FYKNEL)
#length: Total Length (nearest mm) at capture
#weight: Weight (nearest 0.1 or 1 g) at capture

a <- ggplot(data = perch, aes(x = length, y = weight)) +
 geom_point() 

# What makes this not publication quality? 
# 1. Fix labels

a + labs(x = "Length (mm)", y = "Weight (g)")

# A bit too small still - get to that later
a <- a + labs(x = "Length (mm)", y = "Weight (g)") # lock in this new plot

# 2. Equalize data density

a + scale_y_log10() # not good enough

a + scale_y_log10() + scale_x_log10() # great!

# Note about logs:
log(10) # R uses natural log by default
log10(10) # log10 uses... log10

# 2A) Fix the x scale
# Plotting in log space has left blank space on our plot
# Let's fix it!

a + scale_y_log10() + scale_x_log10(limits = c(25, 300)) 

# Better data density, but now we need more ticks!

a + scale_y_log10() +
 scale_x_log10(limits = c(25, 300),
                breaks= seq(from=25, to=300, by=75)) 


# Better

a <- a + scale_y_log10() +
  scale_x_log10(limits = c(25, 300),
                breaks= seq(from=25, to=300, by=75)) 


# 3) Change the background aesthetic

a + theme_bw()

a + theme_dark()
a + theme_classic()
a + theme_linedraw()
a + theme_minimal()

# For fun:

# https://jrnold.github.io/ggthemes/

a + theme_tufte()
a + theme_base()

a + theme_economist()
a + theme_wsj()
a + theme_fivethirtyeight()

a + theme_excel()

# 4) Deal with overplotting 

# Since we're doing a different geom_point we have to remake the whole plot
a <- ggplot(data = perch, aes(x = length, y = weight)) +
  geom_point(shape=1) + #Use an open circled
  scale_y_log10() +
  scale_x_log10(limits = c(25, 300),
                breaks= seq(from=25, to=300, by=75)) +
  labs(x = "Length (mm)", y = "Weight (g)") +
  theme_bw()

a

#5. Final polish

# Axes labels could be a bit bigger

a + theme(axis.text = element_text(size=16),
        axis.title = element_text(size=18))
  
?theme()

# Recap to this point:

# Code to make figure - 

a <- ggplot(data = perch, aes(x = length, y = weight)) +
  geom_point(shape=1) + #Use an open circled
  scale_y_log10() +
  scale_x_log10(limits = c(25, 300),
                breaks= seq(from=25, to=300, by=75)) +
  labs(x = "Length (mm)", y = "Weight (g)") +
  theme(axis.text = element_text(size=16),
        axis.title = element_text(size=18)) +
  theme_bw() 


#6. Output publication-quality

ggsave("./plots/Figure1.tiff", # save in the /plots subfolder
       dpi=300, #300 DPI
       width = 15, height = 10, #15 wide, 10 high
       device = "tiff", #export as tiff
       compression = "lzw",
       units = "cm") # Units are cm

####################################################################
# DOING IT IN BASE PLOT                                            #
####################################################################

plot(weight ~ length, data=perch)

# 1. Fix labels

plot(weight ~ length, data=perch,
     xlab = "Length (mm)",
     ylab = "Weight (g)")

# 2. Data density 

plot(log10(weight) ~ log10(length), data=perch,
     xlab = "Length (mm)",
     ylab = "Weight (g)") #oops, now X axis is wrong!

# One solution
plot(log10(weight) ~ log10(length), data=perch,
     xlab = "Length (log mm)",
     ylab = "Weight (log g)")
 
# ANother solution: make a manually specified X axis
# Don't do this. Just use ggplot

# Problem: blank space

plot(log10(weight) ~ log10(length), data=perch,
     xlab = "Length (log mm)",
     ylab = "Weight (log g)",
     xlim=c(1.4,2.5))

# 3. Themes
# 
# Not in base plot

plot(log10(weight) ~ log10(length), data=perch,
     xlab = "Length (log mm)",
     ylab = "Weight (log g)",
     xlim=c(1.4,2.5))

grid(lty = 1) #sloppy.

# Solution: Draw a blank graph
# then add the grid
# THEN draw the points

plot(log10(weight) ~ log10(length), data=perch,
     xlab = "Length (log mm)",
     ylab = "Weight (log g)",
     xlim=c(1.4,2.5),
     pch="") # Makes the plot blank

grid(lty = 1) 
points(log10(weight) ~ log10(length), data=perch)


# Show how you can make a blank plot then add a grid then add points

# 4. Overplotting not a problem
# But here's how to specify character:

plot(log10(weight) ~ log10(length), data=perch,
     xlab = "Length (log mm)",
     ylab = "Weight (log g)",
     xlim=c(1.4,2.5),
     pch=8) 

grid(lty = 1) 
points(log10(weight) ~ log10(length), data=perch)

# 5. Final polish - expand axis labels

plot(log10(weight) ~ log10(length), data=perch,
     xlab = "Length (log mm)",
     ylab = "Weight (log g)",xlim=c(1.4,2.5),
     pch="",
     cex.axis=1.4,
     cex.lab=1.6) 

grid(lty = 1) 
points(log10(weight) ~ log10(length), data=perch)


# 6. Export

# START by defining the file name and its parameters
tiff(filename = "./plots/Figure1-base.tiff",
     width = 15, height = 10, units = "cm", 
     res = 300,
     compression ="lzw")

# Everything to do with the plot comes next
plot(log10(weight) ~ log10(length), data=perch,
     xlab = "Length (log mm)",
     ylab = "Weight (log g)",xlim=c(1.4,2.5),
     pch="",
     cex.axis=1.4,
     cex.lab=1.6) 

grid(lty = 1) 
points(log10(weight) ~ log10(length), data=perch)

# THEN close it off with dev.off()

dev.off()


# A note about log:
# log() is natural log
log(10)
# log10() is log base 10 
log10(10)

##############################
# Discrete X, Continuous Y   #
##############################

b <- ggplot(data = perch, aes(x = gearid, y=length))

b + geom_boxplot()

# First, let's lock in some aesthetic fixes

b <- ggplot(data = perch, aes(x = gearid, y=length)) +
  labs(x = "Gear ID", y = "Length (mm)") + 
  theme(axis.text = element_text(size=16),
        axis.title = element_text(size=18)) +
  theme_bw() 
  
 
b + geom_boxplot() +
  theme(axis.text.x = element_text(angle=90, hjust=1))

# Combine categories using case_when()

levels(perch$gearid)

perch <- perch %>%
  mutate(combinedgear = as.factor(
    case_when(
    gearid == "FYKNED" ~ "FYK",
    gearid == "FYKNEL" ~ "FYK",
    gearid == "FYKNET" ~ "FYK",
    gearid == "VGN019" ~ "VGN",
    gearid == "VGN025" ~ "VGN",
    gearid == "VGN032" ~ "VGN",
    gearid == "VGN038" ~ "VGN",
    gearid == "VGN089" ~ "VGN",
    gearid == "BSEINE" ~ "BSEINE",
    gearid == "CRAYTR" ~ "CRAYTR",
    gearid == "ELFISH" ~ "ELFISH",
    gearid == "MINNOW" ~ "MINNOW",
    gearid == "TRAMML" ~ "TRAMML",
    TRUE ~ "missing")
  )) 

levels(perch$combinedgear)

c <- ggplot(data = perch, aes(x = combinedgear, y=length)) +
  geom_boxplot() +
  labs(x = "Gear ID", y = "Length (mm)") + 
  theme(axis.text = element_text(size=16),
        axis.title = element_text(size=18)) +
  theme_bw() +
  theme(axis.text.x = element_text(angle=90, hjust=1))

print(c)

# 3. Reorder factors

# Use the forcats package, embedded in tidyverse

# Option 1; Go smallest to largest

c <- ggplot(data = perch, aes(x = fct_reorder(combinedgear, length),
                              y=length)) +
  geom_boxplot() +
  labs(x = "Gear ID", y = "Length (mm)") + 
  theme(axis.text = element_text(size=16),
        axis.title = element_text(size=18)) +
  theme_bw() +
  theme(axis.text.x = element_text(angle=90, hjust=1))

print(c)

# Option 2: Smallest to largest, but with a control group on left

# Let's say "ELFISH" was our "control" group

c <- ggplot(data = perch, aes(x =
                                fct_relevel(
                                  fct_reorder(combinedgear, length),
                                 "ELFISH"),
                              
                              y=length)) +
  geom_boxplot() +
  labs(x = "Gear ID", y = "Length (mm)") + 
  theme_bw() +
  theme(axis.text.x = element_text(angle=90, hjust=1)) 

print(c)

# Expand the axes
c + theme(axis.text = element_text(size=16),
          axis.title = element_text(size=18)) 

# Let's add original data (need to remake the full plot so we can get layering right)

c <- ggplot(data = perch, aes(x =
                                fct_relevel(
                                  fct_reorder(combinedgear, length),
                                  "ELFISH"),
                              
                              y=length)) +
  geom_jitter(colour="grey", alpha=0.5) +
  geom_boxplot(alpha=0.8) +
  labs(x = "Gear ID", y = "Length (mm)") + 
  theme_bw() +
  theme(axis.text.x = element_text(angle=90, hjust=1),
        axis.text = element_text(size=16),
        axis.title = element_text(size=18)
  )

print(c)

ggsave("./plots/Figure2.tiff", # save in the /plots subfolder
       dpi=300, #300 DPI
       width = 15, height = 10, #15 wide, 10 high
       device = "tiff", #export as tiff
       compression = "lzw",
       units = "cm") # Units are cm
